==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-session/lxqt-session/lxqt-session_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="289"/>
        <source>Crash Report</source>
        <translation>Отчёт о падении</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="290"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; упало слишком много раз. Его автозапуск был отменён до следующего входа в систему.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Добро пожаловать в LXQt</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Добро пожаловать в LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Пожалуйста, выберите оконный менеджер по умолчанию.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Вы сможете изменить это в любое время через Настройки -&gt; Настройки сессии -&gt; Основные настройки.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Другое ...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Выберите то, что вам больше нравится.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-session/lxqt-session_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="302"/>
        <source>Crash Report</source>
        <translation>Отчёт о падении</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="303"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; упало слишком много раз. Его автозапуск был отменён до следующего входа в систему.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Добро пожаловать в LXQt</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Добро пожаловать в LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Пожалуйста, выберите оконный менеджер по умолчанию.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Вы сможете изменить это в любое время через Настройки -&gt; Настройки сессии -&gt; Основные настройки.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>Другое ...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>Выберите то, что вам больше нравится.</translation>
    </message>
</context>
</TS>
